@@ -2,7 +2,7 @@ package Fl;
 use 5.008001;
 use strict;
 use warnings;
-our $VERSION = '0.99.3';
+our $VERSION = '0.99.4';
 use XSLoader;
 use vars qw[@EXPORT_OK @EXPORT %EXPORT_TAGS];
 use Exporter qw[import];
@@ -19,7 +19,7 @@ $EXPORT_TAGS{'all'} = \@EXPORT_OK;    # When you want to import everything
     if 1 < scalar keys %EXPORT_TAGS;
 @{$EXPORT_TAGS{'enum'}}               # Merge these under a single tag
     = sort map { defined $EXPORT_TAGS{$_} ? @{$EXPORT_TAGS{$_}} : () }
-    qw[box chart color font label version]
+    qw[box button chart color font keyboard label mouse version when]
     if 1 < scalar keys %EXPORT_TAGS;
 @EXPORT    # Export these tags (if prepended w/ ':') or functions by default
     = sort map { m[^:(.+)] ? @{$EXPORT_TAGS{$1}} : $_ } qw[:style :default]
@@ -82,6 +82,18 @@ Fl::Enumerations.
 Static variables and utility functions related to colors may be found in
 Fl::Color.
 
+=head2 C<:keyboard>
+
+    use Fl qw[:keyboard];
+
+Event and state values for keyboard buttons.
+
+=head2 C<:mouse>
+
+    use Fl qw[:mouse];
+
+Event and state values for mouse buttons.
+
 =head1 Classes
 
 Fl contains several widgets and other classes including:
@@ -90,6 +102,8 @@ Fl contains several widgets and other classes including:
 
 =item L<Fl::Box>
 
+=item L<Fl::Button>
+
 =item L<Fl::Chart>
 
 =item L<Fl::Group>
