@@ -3,6 +3,7 @@
 #include <FL/Fl_Widget.H>
 #include <FL/Fl_Group.H>
 #include <FL/Fl_Box.H>
+#include <FL/Fl_Button.H>
 #include <FL/Fl_Window.H>
 #include <FL/Fl_Chart.H>
 
@@ -10,8 +11,9 @@ const char * object2package (Fl_Widget * w) {
     /*Remember to add _most_ specific classes first*/
     const char * package = "Fl::Widget";
          if ( dynamic_cast<Fl_Box    *>(w) ) { package = "Fl::Box";    }
+    else if ( dynamic_cast<Fl_Button *>(w) ) { package = "Fl::Button"; }
     else if ( dynamic_cast<Fl_Window *>(w) ) { package = "Fl::Window"; }
     else if ( dynamic_cast<Fl_Group  *>(w) ) { package = "Fl::Group";  }
-    else if ( dynamic_cast<Fl_Chart *>(w) ) { package = "Fl::Chart"; }
+    else if ( dynamic_cast<Fl_Chart  *>(w) ) { package = "Fl::Chart";  }
     return package;
 }
